@@ -111,7 +111,9 @@ void Curve::draw(Gnome::Canvas::Canvas &canvas,
   line->property_width_units() = line_width;
   
 
-  double max = std::max(monitor->max(), 0.000001); // avoid division by zero
+  double max = monitor->max();
+  if (max <= 0)
+    max = 0.0000001;
 
   Gnome::Canvas::Points points;
   points.reserve(value_history.values.size());
@@ -121,6 +123,8 @@ void Curve::draw(Gnome::Canvas::Canvas &canvas,
 	
   do {
     double y = line_width/2 + (1 - (*vi / max)) * (height - line_width/2);
+    if (y < 0)
+      y = 0;
 
     points.push_back(Gnome::Art::Point(x, y));
     x -= CurveView::pixels_per_sample;
