@@ -236,11 +236,11 @@ Precision decimal_digits(double val, int n)
 int const CpuUsageMonitor::max_no_cpus = GLIBTOP_NCPU;
 
 CpuUsageMonitor::CpuUsageMonitor()
-  : cpu_no(all_cpus), total_time(0), nice_time(0), idle_time(0)
+  : cpu_no(all_cpus), total_time(0), nice_time(0), idle_time(0), iowait_time(0)
 {}
 
 CpuUsageMonitor::CpuUsageMonitor(int cpu)
-  : cpu_no(cpu), total_time(0), nice_time(0), idle_time(0)
+  : cpu_no(cpu), total_time(0), nice_time(0), idle_time(0), iowait_time(0)
 {
   if (cpu_no < 0 || cpu_no >= max_no_cpus)
     cpu_no = all_cpus;
@@ -252,33 +252,37 @@ double CpuUsageMonitor::do_measure()
 	
   glibtop_get_cpu(&cpu);
 
-  guint64 t, n, i;
+  guint64 t, n, i, io;
 	
   if (cpu_no == all_cpus) {
     t = cpu.total;
     n = cpu.nice;
     i = cpu.idle;
+    io = cpu.iowait;
   }
   else {
     t = cpu.xcpu_total[cpu_no];
     n = cpu.xcpu_nice[cpu_no];
     i = cpu.xcpu_idle[cpu_no];
+    io = cpu.xcpu_iowait[cpu_no];
   }
 	
   // calculate ticks since last call
   guint64
     dtotal = t - total_time,
     dnice = n - nice_time,
-    didle = i - idle_time; 
+    didle = i - idle_time,
+    diowait = io - iowait_time;
 
   // and save the new values
   total_time = t;
   nice_time = n;
   idle_time = i;
+  iowait_time = io;
 
   // don't count in dnice to avoid always showing 100% with SETI@home and
   // similar applications running
-  double res = double(dtotal - dnice - didle) / dtotal;
+  double res = double(dtotal - dnice - didle - diowait) / dtotal;
 
   if (res > 0)
     return res;
