@@ -43,6 +43,8 @@ public:
   void measure()
   {
     measured_value = do_measure();
+    if (measured_value < 0) // safety check
+      measured_value = 0;
   }
   
   // fetch the currently measured value
